@@ -5,7 +5,7 @@ use warnings;
 
 use MooX::ReturnModifiers;
 
-our $VERSION = '1.012001';
+our $VERSION = '1.012002';
 
 sub import {
 	my $target	= caller;
@@ -26,12 +26,19 @@ sub import {
 							my ( $orig, $self, @params ) = @_;
 							my $current_spec = $self->$store_spec;
 
+							@params = $self->_preprocess_params(@params);
+
 							if ( my $param_spec = $current_spec->{params} ) {
 								@params = $self->_validate_sub(
 									$name, 'params', $param_spec, @params
 								);
 							}
 
+							if (my $keys = $current_spec->{keys}) {
+								my $hash = scalar @params > 1 ? { @params } : $params[0];
+								@params = map { $hash->{$_} } @{ $keys };
+							}
+
 							@params = $self->$orig(@params);
 
 							if ( my $param_spec = $current_spec->{returns} ) {
@@ -68,7 +75,7 @@ MooX::ValidateSubs - Validating sub routines via Type::Tiny.
 
 =head1 VERSION
 
-Version 1.012001
+Version 1.012002
 
 =cut
 
@@ -95,6 +102,17 @@ Version 1.012001
 			},
 		},
 		goodbye_world => { params => [ [Str], [ArrayRef], [HashRef] ] },
+		spec => {
+			params => {
+				one   => [ Str, sub { 'one' } ],
+				two   => [ Str, sub { 'two' } ],
+				three => [ Str, sub { 'three' } ],
+			},
+			keys => [qw/three two one/]
+		},
+		indexed => {
+			params => [ [Str, sub { 'one' }], [Str, sub { 'two' }], [Str, sub { 'three' }] ],
+		},
 	);
 
 	sub before_add_me {
@@ -121,6 +139,8 @@ Version 1.012001
 		return %args;
 	}
 
+	$self->indexed('2=changed'); # one, two, changed
+
 =head1 Exports
 
 =head2 validate_subs
